@@ -116,8 +116,8 @@ class Viewer(ViewerParent):
     _model_name = Unicode('ViewerModel').tag(sync=True)
     _view_module = Unicode('itkwidgets').tag(sync=True)
     _model_module = Unicode('itkwidgets').tag(sync=True)
-    _view_module_version = Unicode('^0.28.0').tag(sync=True)
-    _model_module_version = Unicode('^0.28.0').tag(sync=True)
+    _view_module_version = Unicode('^0.28.1').tag(sync=True)
+    _model_module_version = Unicode('^0.28.1').tag(sync=True)
     image = ITKImage(
         default_value=None,
         allow_none=True,
@@ -515,7 +515,7 @@ class Viewer(ViewerParent):
             if self.image:
                 self.rendered_image = self.image
             if self.label_map:
-                self.rendered_label_map = self.image
+                self.rendered_label_map = self.label_map
 
     @validate('label_map_weights')
     def _validate_label_map_weights(self, proposal):
